@@ -14,6 +14,7 @@ from command_list import CommandList
 from command_init import CommandInit
 from command_push import CommandPush
 from command_pull import CommandPull
+from command_mkdir import CommandMkdir
 from command_search import CommandSearch
 from command_trash import CommandTrash
 
@@ -94,6 +95,7 @@ def main():
     drive_commands = {'list': CommandList(subparser),
                       'push': CommandPush(subparser),
                       'pull': CommandPull(subparser),
+                      'mkdir': CommandMkdir(subparser),
                       'search': CommandSearch(subparser),
                       'trash': CommandTrash(subparser),
                       'init': CommandInit(subparser)}
